package
Version:
v0.0.6
Opens a new window with list of versions in this module.
Published: Jun 21, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Certificate struct {
DNS string `json:"dns"`
Info *cert.Cert `json:"info"`
}
Certificate stores the dns name, the information about the cert, and possible errors
Source Files
¶
Click to show internal directories.
Click to hide internal directories.