Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Controller ¶
type Controller struct {
// contains filtered or unexported fields
}
Controller probes certificates and registers the result in the metrics server
func New ¶
func New(interval time.Duration, servingAddress string, log *logrus.Entry, certs []models.Certificate) *Controller
New returns a new configured instance of the Controller struct
func (*Controller) Certs ¶ added in v0.0.4
func (c *Controller) Certs() []models.Certificate
Certs exposes certificate info to external services
func (*Controller) Run ¶
func (c *Controller) Run(ctx context.Context) error
Run starts the main loop that will call ProbeAll regularly.
func (*Controller) Shutdown ¶ added in v0.0.4
func (c *Controller) Shutdown() error
Shutdown closes the metrics server gracefully
Click to show internal directories.
Click to hide internal directories.